@@ -1,7 +1,7 @@
 package App::short;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-01-13'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -216,9 +216,7 @@ sub list_shorts {
 
     my %resmeta;
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {table_column_orders=>[[qw/name target is_broken/]]},
-        };
+        $resmeta{'table.fields'} = [qw/name target is_broken/];
     } else {
         @res = map {$_->{name}} @res;
     }
@@ -266,9 +264,7 @@ sub list_longs {
 
     my %resmeta;
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {table_column_orders=>[[qw/name/]]},
-        };
+        $resmeta{'table.fields'} = [qw/name/];
     } else {
         @res = map {$_->{name}} @res;
     }
@@ -308,9 +304,7 @@ sub list_missing {
 
     my %resmeta;
     if ($args{detail}) {
-        $resmeta{format_options} = {
-            any => {table_column_orders=>[[qw/name/]]},
-        };
+        $resmeta{'table.fields'} = [qw/name/];
     } else {
         @res = map {$_->{name}} @res;
     }
@@ -318,6 +312,50 @@ sub list_missing {
     [200, "OK", \@res];
 }
 
+$SPEC{list_duplicates} = {
+    v => 1.1,
+    args => {
+        %common_args,
+        %detail_l_arg,
+    },
+};
+sub list_duplicates {
+    use experimental 'smartmatch';
+
+    my %args = @_;
+    my $res = _validate(\%args);
+    return $res unless $res->[0] == 200;
+
+    my $S = $args{short_dir};
+    my $L = $args{long_dir};
+
+    my $res_s = list_shorts(_common_args(\%args), broken=>0, detail=>1);
+
+    my %mentioned_longs;
+    for my $e (@{ $res_s->[2] }) {
+        push @{ $mentioned_longs{ $e->{target} } }, $e->{name};
+    }
+
+    my @res;
+    for (sort keys %mentioned_longs) {
+        my $names = $mentioned_longs{$_};
+        next unless @$names > 1;
+        push @res, {
+            target => $_,
+            names => join(", ", @$names),
+        };
+    }
+
+    my %resmeta;
+    if ($args{detail}) {
+        $resmeta{'table.fields'} = [qw/target names/];
+    } else {
+        @res = map {$_->{target}} @res;
+    }
+
+    [200, "OK", \@res, \%resmeta];
+}
+
 $SPEC{get_short_target} = {
     v => 1.1,
     args => {
@@ -445,7 +483,7 @@ App::short - Manage short directory symlinks
 
 =head1 VERSION
 
-This document describes version 0.09 of App::short (from Perl distribution App-short), released on 2015-09-12.
+This document describes version 0.10 of App::short (from Perl distribution App-short), released on 2017-01-13.
 
 =head1 SYNOPSIS
 
@@ -456,6 +494,8 @@ Please see L<short> script.
 
 =head2 add_short(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -486,6 +526,8 @@ Return value:  (any)
 
 =head2 get_short_target(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -512,8 +554,40 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 list_duplicates(%args) -> [status, msg, result, meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<detail> => I<bool>
+
+=item * B<long_dir>* => I<str>
+
+=item * B<long_include> => I<array[str]>
+
+=item * B<short_dir>* => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 list_longs(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -542,6 +616,8 @@ Return value:  (any)
 
 =head2 list_missing(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -570,6 +646,8 @@ Return value:  (any)
 
 =head2 list_shorts(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -602,6 +680,8 @@ Return value:  (any)
 
 =head2 rm_short(%args) -> [status, msg, result, meta]
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -633,7 +713,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-short>
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-short>.
+Source repository is at L<https://github.com/perlancar/perl-App-projdir>.
 
 =head1 BUGS
 
@@ -649,7 +729,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
